# Welcome To Contributing Guide
Any contribution done to this repository will be appreciated! 🎉

### About Ultroid
- **Ultroid** is Telegram Userbot, which allow you to perform many task easily. 
- It's base core is a pip package named [`pyJarvis`](https://GitHub.com/TeamUltroid/pyJarvis).
- This repository, contains Ultroid's official plugin files.
- moreover, Ultroid User also have an option to get more plugins available at [`UltroidAddons`](https://github.com/MrCode403/JarvesAddons)

### Issues
- Search for existing Similar issues.
- You can open a issue first before contributing, If it contain some major changes like `bug fixes` or `feature addition`.
- If you are busy or getting trouble while making changes, you can just open the issue (explaining it).

### Contributing
- You can [fork](https://github.com/MrCode403/Jarves/fork) this repository.
- You can commits your changes now.
- You can [Git-Squash](https://docs.github.com/en/get-started/using-git/about-git-rebase) your commits, if they are more. [Optional]
- At last, You are ready to [`make a Pull Request`](https://docs.github.com/en/github/collaborating-with-pull-requests/proposing-changes-to-your-work-with-pull-requests/creating-a-pull-request).
- Make sure that, your `Pull Request` contain an explaining title and issue number if it closes any open issue.

### Thanks
- Congrats! 💫 you have successfully made your Contribution to Ultroid.
